@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -469,9 +469,9 @@ public class SVNCommandUtil {
         }
         if (!quiet) {
             message += 
-                "\nCopyright (c) 2004-2010 TMate Software.\n" +
-                "SVNKit is open source (GPL) software, see http://svnkit.com/ for more information.\n" +
-                "SVNKit is pure Java (TM) version of Subversion, see http://subversion.tigris.org/";
+                "\nCopyright (c) 2004-2011 TMate Software.\n" +
+                "SVNKit is an Open Source software, see http://svnkit.com/ for more information.\n" +
+                "SVNKit is a pure Java (TM) version of Subversion, see http://subversion.tigris.org/";
         }
         return message;
     
