@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -34,6 +34,7 @@ import org.tmatesoft.svn.core.auth.SVNSSLAuthentication;
 import org.tmatesoft.svn.core.auth.SVNUserNameAuthentication;
 import org.tmatesoft.svn.core.internal.util.SVNSSLUtil;
 import org.tmatesoft.svn.core.internal.wc.ISVNAuthStoreHandler;
+import org.tmatesoft.svn.core.internal.wc.ISVNSSLPasspharsePromptSupport;
 import org.tmatesoft.svn.core.wc.SVNWCUtil;
 
 
@@ -41,7 +42,7 @@ import org.tmatesoft.svn.core.wc.SVNWCUtil;
  * @version 1.0
  * @author  TMate Software Ltd.
  */
-public class SVNConsoleAuthenticationProvider implements ISVNAuthenticationProvider, ISVNAuthStoreHandler {
+public class SVNConsoleAuthenticationProvider implements ISVNAuthenticationProvider, ISVNSSLPasspharsePromptSupport, ISVNAuthStoreHandler {
     
     private static final String OUR_PASSPHRASE_PROMPT_TEXT = "-----------------------------------------------------------------------\n" +
                                                              "ATTENTION!  Your passphrase for client certificate:\n" +
@@ -69,6 +70,8 @@ public class SVNConsoleAuthenticationProvider implements ISVNAuthenticationProvi
                                                              "of the ''store-plaintext-passwords'' option to either ''yes'' or ''no'' in\n" +
                                                              "''{1}''.\n" +
                                                              "-----------------------------------------------------------------------\n";
+
+    private static final String OUR_HOST_KEY_PROMPT_TEXT =   "The ''{0}'' server''s key fingerprint is:\n{1}\n";
     
     private static final String OUR_PASSWORD_PROMPT_STRING = "Store password unencrypted (yes/no)? ";
     private static final String OUR_PASSPHRASE_PROMPT_STRING = "Store passphrase unencrypted (yes/no)? ";
@@ -81,6 +84,40 @@ public class SVNConsoleAuthenticationProvider implements ISVNAuthenticationProvi
     }
     
     public int acceptServerAuthentication(SVNURL url, String realm, Object certificate, boolean resultMayBeStored) {
+        
+        if (certificate instanceof byte[]) {
+            StringBuffer prompt = new StringBuffer(OUR_HOST_KEY_PROMPT_TEXT);
+            if (resultMayBeStored) {
+                prompt.append("If you trust this host, enter ''p'' to add the key to the SVN cache and carry on connecting.\n");
+                prompt.append("If you want to carry on connecting just once, without adding the key to the cache, type ''t''.");
+                prompt.append("If you do not trust this host, type ''R'' to abandon the connection.");
+                prompt.append("\n(R)eject, accept (t)emporarily or accept (p)ermanently? "); 
+            } else {
+                prompt.append("If you want to carry on connecting just once, without adding the key to the cache, type ''t''.");
+                prompt.append("If you do not trust this host, type ''R'' to abandon the connection.");
+                prompt.append("\n(R)eject or accept (t)emporarily? "); 
+            }
+            System.err.print(MessageFormat.format(prompt.toString(), new Object[] {url.getHost(), SVNSSLUtil.getFingerprint((byte[]) certificate)}));
+            System.err.flush();
+            while(true) {
+                String line = readLine();
+                if (line == null) {
+                    return ISVNAuthenticationProvider.REJECTED;
+                }
+                if (line.length() < 1) {
+                    continue;
+                }
+                char ch = line.charAt(0);
+                if (ch == 'R' || ch == 'r') {
+                    return ISVNAuthenticationProvider.REJECTED;
+                } else if (ch == 't' || ch == 'T') {
+                    return ISVNAuthenticationProvider.ACCEPTED_TEMPORARY;
+                } else if (resultMayBeStored && (ch == 'p' || ch == 'P')) {
+                    return ISVNAuthenticationProvider.ACCEPTED;
+                }
+            }
+        }
+        
         if (myIsTrustServerCertificate) {
             return ISVNAuthenticationProvider.ACCEPTED_TEMPORARY;
         }
@@ -308,6 +345,13 @@ public class SVNConsoleAuthenticationProvider implements ISVNAuthenticationProvi
             }            
             return new SVNUserNameAuthentication(name, authMayBeStored, url, false);
         } else if (ISVNAuthenticationManager.SSL.equals(kind)) {
+            if (SVNSSLAuthentication.isCertificatePath(realm)) {
+                String passphrase = promptPassword("Passphrase for '" + realm + "'");
+                if (passphrase == null) {
+                    return null;
+                }
+                return new SVNPasswordAuthentication("", passphrase, authMayBeStored);
+            }
             boolean isMSCAPI = false;
             printRealm(realm);
             String path = null;
@@ -338,13 +382,9 @@ public class SVNConsoleAuthenticationProvider implements ISVNAuthenticationProvi
                 }
                 return new SVNSSLAuthentication(SVNSSLAuthentication.MSCAPI, alias, authMayBeStored, url, false);
             }
-            String password = promptPassword("Passphrase for '" + realm + "'");
-            if (password == null) {
-                return null;
-            } else if ("".equals(password)) {
-                password = null;
-            }
-            return new SVNSSLAuthentication(new File(path), password, authMayBeStored, url, false);
+            SVNSSLAuthentication sslAuth = new SVNSSLAuthentication(new File(path), null, authMayBeStored, url, false);
+            sslAuth.setCertificatePath(path);
+            return sslAuth;
         }
         return null;
     }
@@ -429,4 +469,8 @@ public class SVNConsoleAuthenticationProvider implements ISVNAuthenticationProvi
         }
     }
 
+    public boolean isSSLPassphrasePromtSupported() {
+        return true;
+    }
+
 }
