@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -451,7 +451,12 @@ public class SVNMergeRangeList {
         }
         return SVNMergeRangeList.fromCollection(ranges);
     }
+
+    public SVNMergeRangeList remove(SVNMergeRangeList remove, boolean considerInheritance) {
+        return removeOrIntersect(remove, true, considerInheritance);
+    }
     
+
     private SVNMergeRange combineWithLastRange(Collection rangeList, SVNMergeRange lastRange, SVNMergeRange mRange, boolean dupMRange, boolean considerInheritance) {
         SVNMergeRange pushedMRange1 = null;
         SVNMergeRange pushedMRange2 = null;
@@ -554,12 +559,7 @@ public class SVNMergeRangeList {
                         if (lastRange.getEndRevision() < mRange.getEndRevision()) {
                             if (pushedMRange2 == null) {
                                 pushedMRange2 = new SVNMergeRange(lastRange.getEndRevision(), mRange.getEndRevision(), mRange.isInheritable());
-                            } else {
-                                pushedMRange2.setStartRevision(lastRange.getEndRevision());
-                                pushedMRange2.setEndRevision(mRange.getEndRevision());
-                                pushedMRange2.setInheritable(mRange.isInheritable());
-                            }
-                            
+                            } 
                             tmpRevision = lastRange.getStartRevision();
                             lastRange.setStartRevision(mRange.getStartRevision());
                             lastRange.setEndRevision(tmpRevision);
@@ -571,11 +571,7 @@ public class SVNMergeRangeList {
                         } else {
                             if (pushedMRange2 == null) {
                                 pushedMRange2 = new SVNMergeRange(mRange.getEndRevision(), lastRange.getEndRevision(), lastRange.isInheritable());
-                            } else {
-                                pushedMRange2.setStartRevision(mRange.getEndRevision());
-                                pushedMRange2.setEndRevision(lastRange.getEndRevision());
-                                pushedMRange2.setInheritable(lastRange.isInheritable());
-                            }
+                            } 
                             
                             tmpRevision = lastRange.getStartRevision();
                             lastRange.setStartRevision(mRange.getStartRevision());
@@ -601,5 +597,4 @@ public class SVNMergeRangeList {
         }
         return lastRange;
     }
-    
 }
