@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -507,8 +507,8 @@ public class DAVEditorHandler extends BasicDAVDeltaHandler {
                 } else if (myIsDirectory) {
                     if (myDirs.size() != 1 || !myHasTarget) {
                         try {
-                            myEditor.changeDirProperty(SVNProperty.WC_URL, 
-                                    SVNPropertyValue.create(myHref));
+                            SVNPropertyValue davWCURL = DAVUtil.isUseDAVWCURL() ? SVNPropertyValue.create(myHref) : null;
+                            myEditor.changeDirProperty(SVNProperty.WC_URL, davWCURL);
                         } catch (SVNCancelException ce) {
                             throw ce;
                         } catch (SVNException svne) {                        
@@ -519,8 +519,8 @@ public class DAVEditorHandler extends BasicDAVDeltaHandler {
                     }
                 } else {
                     try {
-                        myEditor.changeFileProperty(myPath, SVNProperty.WC_URL, 
-                                SVNPropertyValue.create(myHref));
+                        SVNPropertyValue davWCURL = DAVUtil.isUseDAVWCURL() ? SVNPropertyValue.create(myHref) : null;
+                        myEditor.changeFileProperty(myPath, SVNProperty.WC_URL, davWCURL);
                     } catch (SVNCancelException ce) {
                         throw ce;
                     } catch (SVNException svne) {
