@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -121,7 +121,9 @@ class HTTPConnection implements IHTTPConnection {
     private boolean myIsSpoolAll;
     private File mySpoolDirectory;
     private long myNextRequestTimeout;
-    
+    private Collection myCookies;
+    private int myRequestCount;
+
     public HTTPConnection(SVNRepository repository, String charset, File spoolDirectory, boolean spoolAll) throws SVNException {
         myRepository = repository;
         myCharset = charset;
@@ -253,6 +255,7 @@ class HTTPConnection implements IHTTPConnection {
     }
     
     public void clearAuthenticationCache() {
+        myCookies = null;
         myLastValidAuth = null;
         myTrustManager = null;
         myKeyManager = null;
@@ -279,6 +282,8 @@ class HTTPConnection implements IHTTPConnection {
     }
     
     public HTTPStatus request(String method, String path, HTTPHeader header, InputStream body, int ok1, int ok2, OutputStream dst, DefaultHandler handler, SVNErrorMessage context) throws SVNException {
+        myRequestCount++;
+        
         if ("".equals(path) || path == null) {
             path = "/";
         }
@@ -344,7 +349,10 @@ class HTTPConnection implements IHTTPConnection {
                         request.setAuthentication(httpAuthResponse);
                     }
 
-                    try {
+                    if (myCookies != null && !myCookies.isEmpty()) {
+                        request.setCookies(myCookies);
+                    }
+                    try {                        
                         request.dispatch(method, path, header, ok1, ok2, context);
                         break;
                     } catch (EOFException pe) {
@@ -358,6 +366,9 @@ class HTTPConnection implements IHTTPConnection {
                         retryCount--;
                     }
                 }
+                if (request.getResponseHeader().hasHeader(HTTPHeader.SET_COOKIE)) {
+                    myCookies = request.getResponseHeader().getHeaderValues(HTTPHeader.COOKIE);
+                }
                 myNextRequestTimeout = request.getNextRequestTimeout();
                 status = request.getStatus();
             } catch (SSLHandshakeException ssl) {
@@ -426,7 +437,7 @@ class HTTPConnection implements IHTTPConnection {
                     authTypes = defaultAuthManager.getAuthTypes(myRepository.getLocation());
                 }
                 try {
-                    myProxyAuthentication = HTTPAuthentication.parseAuthParameters(proxyAuthHeaders, myProxyAuthentication, myCharset, authTypes); 
+                    myProxyAuthentication = HTTPAuthentication.parseAuthParameters(proxyAuthHeaders, myProxyAuthentication, myCharset, authTypes, null, myRequestCount); 
                 } catch (SVNException svne) {
                     myRepository.getDebugLog().logFine(SVNLogType.NETWORK, svne);
                     err = svne.getErrorMessage(); 
@@ -484,13 +495,13 @@ class HTTPConnection implements IHTTPConnection {
                 }
                 
                 try {
-                    myChallengeCredentials = HTTPAuthentication.parseAuthParameters(authHeaderValues, myChallengeCredentials, myCharset, authTypes); 
+                    myChallengeCredentials = HTTPAuthentication.parseAuthParameters(authHeaderValues, myChallengeCredentials, myCharset, authTypes, authManager, myRequestCount); 
                 } catch (SVNException svne) {
                     err = svne.getErrorMessage(); 
                     break;
                 }
 
-                myChallengeCredentials.setChallengeParameter("methodname", method);
+                myChallengeCredentials.setChallengeParameter("method", method);
                 myChallengeCredentials.setChallengeParameter("uri", HTTPParser.getCanonicalPath(path, null).toString());
                 
                 if (skip) {
@@ -738,6 +749,7 @@ class HTTPConnection implements IHTTPConnection {
                 xmlReader.parse(new InputSource(reader));
             }
         } catch (SAXException e) {
+            mySAXParser = null;
             if (e instanceof SAXParseException) {
                 if (handler instanceof DAVErrorHandler) {
                     // failed to read svn-specific error, return null.
@@ -750,6 +762,7 @@ class HTTPConnection implements IHTTPConnection {
             } 
             return SVNErrorMessage.create(SVNErrorCode.RA_DAV_REQUEST_FAILED, "Processing {0} request response failed: {1} ({2}) ",  new Object[] {method, e.getMessage(), path});
         } catch (ParserConfigurationException e) {
+            mySAXParser = null;
             return SVNErrorMessage.create(SVNErrorCode.RA_DAV_REQUEST_FAILED, "XML parser configuration error while processing {0} request response: {1} ({2}) ",  new Object[] {method, e.getMessage(), path});
         } catch (EOFException e) {
             // skip it.
