@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -413,9 +413,7 @@ public class FSCommitEditor implements ISVNEditor {
     private static class DirBaton {
 
         private long myBaseRevision;
-
         private String myPath;
-
         private boolean isCopied;
 
         public DirBaton(long revision, String path, boolean copied) {
@@ -428,25 +426,13 @@ public class FSCommitEditor implements ISVNEditor {
             return isCopied;
         }
 
-        public void setCopied(boolean isCopied) {
-            this.isCopied = isCopied;
-        }
-
         public long getBaseRevision() {
             return myBaseRevision;
         }
 
-        public void setBaseRevision(long baseRevision) {
-            myBaseRevision = baseRevision;
-        }
-
         public String getPath() {
             return myPath;
         }
-
-        public void setPath(String path) {
-            myPath = path;
-        }
     }
 
 }
