@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -284,7 +284,7 @@ public class SVNSaslAuthenticator extends SVNAuthenticator {
                     continue;
                 }
                 SVNAuthentication auth = null;
-                if ("ANONYMOUS".equals(mech) || "PLAIN".equals(mech)) {
+                if ("ANONYMOUS".equals(mech)) {
                     auth = new SVNPasswordAuthentication("", "", false);
                 } else if ("EXTERNAL".equals(mech)) {
                     String name = repos.getExternalUserName();
