@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -44,6 +44,7 @@ import org.tmatesoft.svn.core.internal.util.SVNPathUtil;
 import org.tmatesoft.svn.core.internal.util.SVNURLUtil;
 import org.tmatesoft.svn.core.internal.wc.admin.SVNAdminArea;
 import org.tmatesoft.svn.core.internal.wc.admin.SVNEntry;
+import org.tmatesoft.svn.core.internal.wc.admin.SVNLog;
 import org.tmatesoft.svn.core.internal.wc.admin.SVNVersionedProperties;
 import org.tmatesoft.svn.core.internal.wc.admin.SVNWCAccess;
 import org.tmatesoft.svn.core.io.ISVNEditor;
@@ -760,8 +761,7 @@ public class SVNCopyDriver extends SVNBasicClient {
                     for (Iterator pathsIter = pathsToExternalsProps.keySet().iterator(); pathsIter.hasNext();) {
                         File localPath = (File) pathsIter.next();
                         String externalsPropString = (String) pathsToExternalsProps.get(localPath);
-                        SVNExternal[] externals = SVNExternal.parseExternals(localPath.getAbsolutePath(),
-                                externalsPropString);
+                        SVNExternal[] externals = SVNExternal.parseExternals(localPath, externalsPropString);
                         boolean introduceVirtualExternalChange = false;
                         newExternals.clear();
                         for (int k = 0; k < externals.length; k++) {
@@ -797,9 +797,21 @@ public class SVNCopyDriver extends SVNBasicClient {
                                 // property or no url in it?
                                 continue;
                             }
+                            
+                            SVNURL resolvedURL = externals[k].resolveURL(repos.getRepositoryRoot(true), ownerURL);
+                            String unresolvedURL = externals[k].getUnresolvedUrl();
+                            if (unresolvedURL != null && !SVNPathUtil.isURL(unresolvedURL) && unresolvedURL.startsWith("../"))  {
+                                unresolvedURL = SVNURLUtil.getRelativeURL(repos.getRepositoryRoot(true), resolvedURL);
+                                if (unresolvedURL.startsWith("/")) {
+                                    unresolvedURL = "^" + unresolvedURL;
+                                } else {
+                                    unresolvedURL = "^/" + unresolvedURL;
+                                }
+                            }
+
                             SVNRevision[] revs = externalsHandler.handleExternal(
                                     externalWC,
-                                    externals[k].resolveURL(repos.getRepositoryRoot(true), ownerURL),
+                                    resolvedURL,
                                     externals[k].getRevision(),
                                     externals[k].getPegRevision(),
                                     externals[k].getRawValue(),
@@ -807,10 +819,13 @@ public class SVNCopyDriver extends SVNBasicClient {
 
                             if (revs != null && revs[0].equals(externals[k].getRevision())) {
                                 newExternals.add(externals[k].getRawValue());
-                            } else if (revs != null) {
+                            } else if (revs != null) {                                
                                 SVNExternal newExternal = new SVNExternal(externals[k].getPath(),
-                                        externals[k].getUnresolvedUrl(), revs[1],
-                                        revs[0], true, externals[k].isPegRevisionExplicit(),
+                                        unresolvedURL,
+                                        revs[1],
+                                        revs[0], 
+                                        true, 
+                                        externals[k].isPegRevisionExplicit(),
                                         externals[k].isNewFormat());
 
                                 newExternals.add(newExternal.toString());
@@ -1107,6 +1122,7 @@ public class SVNCopyDriver extends SVNBasicClient {
             try {
                 os = SVNFileUtil.openFileForWriting(tmpFile);
                 revision = topSrcRepos.getFile(path, srcRevNum, props, new SVNCancellableOutputStream(os, this));
+                props = SVNMergeDriver.filterProperties(props, true, false, false, true);
             } finally {
                 SVNFileUtil.closeFile(os);
             }
@@ -1312,7 +1328,7 @@ public class SVNCopyDriver extends SVNBasicClient {
                 try {
                     // do real copy.
                     File sourceFile = new File(pair.mySource);
-                    copyFiles(sourceFile, new File(dstParentPath), dstAccess, pair.myBaseName);
+                    copyFiles(sourceFile, new File(dstParentPath), dstAccess, pair.myBaseName, false);
                 } finally {
                     if (srcAccess != null && srcAccess != dstAccess) {
                         close(srcAccess);
@@ -1355,7 +1371,7 @@ public class SVNCopyDriver extends SVNBasicClient {
                         dstAccess.open(dstParent, true, 0);
                     }
                 }
-                copyFiles(sourceFile, dstParent, dstAccess, pair.myBaseName);
+                copyFiles(sourceFile, dstParent, dstAccess, pair.myBaseName, true);
                 // delete src.
                 SVNWCManager.delete(srcAccess, srcAccess.getAdminArea(srcParent), sourceFile, true, true);
             } finally {
@@ -1368,7 +1384,7 @@ public class SVNCopyDriver extends SVNBasicClient {
         sleepForTimeStamp();
     }
 
-    private void copyFiles(File src, File dstParent, SVNWCAccess dstAccess, String dstName) throws SVNException {
+    private void copyFiles(File src, File dstParent, SVNWCAccess dstAccess, String dstName, boolean move) throws SVNException {
         SVNWCAccess srcAccess = getWCAccess();
         try {
             probeOpen(srcAccess, src, false, -1);
@@ -1389,13 +1405,13 @@ public class SVNCopyDriver extends SVNBasicClient {
             }
             SVNFileType srcType = SVNFileType.getType(src);
             if (srcType == SVNFileType.FILE || srcType == SVNFileType.SYMLINK) {
-                if (srcEntry.isScheduledForAddition() && !srcEntry.isCopied()) {
+                if (srcEntry.isScheduledForAddition() && !(srcEntry.isCopied() && srcEntry.getCopyFromURL() != null)) {
                     copyAddedFileAdm(src, srcAccess, dstAccess, dstParent, dstName, true);
                 } else {
-                    copyFileAdm(src, srcAccess, dstParent, dstAccess, dstName);
+                    copyFileAdm(src, srcAccess, dstParent, dstAccess, dstName, move);
                 }
             } else if (srcType == SVNFileType.DIRECTORY) {
-                if (srcEntry.isScheduledForAddition() && !srcEntry.isCopied()) {
+                if (srcEntry.isScheduledForAddition() && !(srcEntry.isCopied() && srcEntry.getCopyFromURL() != null)) {
                     copyAddedDirAdm(src, srcAccess, dstParent, dstAccess, dstName, true);
                 } else {
                     copyDirAdm(src, srcAccess, dstAccess, dstParent, dstName);
@@ -1406,7 +1422,7 @@ public class SVNCopyDriver extends SVNBasicClient {
         }
     }
 
-    private void copyFileAdm(File src, SVNWCAccess srcAccess, File dstParent, SVNWCAccess dstAccess, String dstName) throws SVNException {
+    private void copyFileAdm(File src, SVNWCAccess srcAccess, File dstParent, SVNWCAccess dstAccess, String dstName, boolean move) throws SVNException {
         File dst = new File(dstParent, dstName);
         SVNFileType dstType = SVNFileType.getType(dst);
         if (dstType != SVNFileType.NONE) {
@@ -1436,6 +1452,7 @@ public class SVNCopyDriver extends SVNBasicClient {
             copyFromURL = srcEntry.getURL();
             copyFromRevision = srcEntry.getRevision();
         }
+        String changelistName = srcEntry.getChangelistName();
         // copy base file.
         File srcBaseFile = new File(src.getParentFile(), SVNAdminUtil.getTextBasePath(src.getName(), false));
         File dstBaseFile = new File(dstParent, SVNAdminUtil.getTextBasePath(dstName, true));
@@ -1443,24 +1460,46 @@ public class SVNCopyDriver extends SVNBasicClient {
         SVNVersionedProperties srcBaseProps = srcDir.getBaseProperties(src.getName());
         SVNVersionedProperties srcWorkingProps = srcDir.getProperties(src.getName());
 
-        // copy wc file.
         SVNAdminArea dstDir = dstAccess.getAdminArea(dstParent);
-        File tmpWCFile = SVNAdminUtil.createTmpFile(dstDir);
         if (srcWorkingProps.getPropertyValue(SVNProperty.SPECIAL) != null) {
-            // TODO create symlink there?
-            SVNFileUtil.copyFile(src, tmpWCFile, false);
-        } else {
-            SVNFileUtil.copyFile(src, tmpWCFile, false);
-        }
-        SVNWCManager.addRepositoryFile(dstDir, dstName, tmpWCFile, null, srcBaseProps.asMap(), srcWorkingProps.asMap(), copyFromURL, copyFromRevision);
+            SVNWCManager.addRepositoryFile(dstDir, dstName, null, srcBaseFile, srcBaseProps.asMap(), srcWorkingProps.asMap(), copyFromURL, copyFromRevision);
 
+            String sourceLinkTarget = SVNFileUtil.getSymlinkName(src);
+            String targetLinkTarget = SVNFileUtil.getSymlinkName(dst);
+            if (sourceLinkTarget != null && !sourceLinkTarget.equals(targetLinkTarget)) {
+                SVNFileUtil.deleteFile(dst);
+                SVNFileUtil.createSymlink(dst, sourceLinkTarget);
+            }
+        } else {
+            File tmpWCFile = SVNAdminUtil.createTmpFile(dstDir);
+            SVNFileUtil.copyFile(src, tmpWCFile, false);
+            SVNWCManager.addRepositoryFile(dstDir, dstName, tmpWCFile, null, srcBaseProps.asMap(), srcWorkingProps.asMap(), copyFromURL, copyFromRevision);
+        }
+        
+        if (changelistName != null && move) {
+            dstEntry = dstAccess.getEntry(dst, false);
+            if (dstEntry != null) {
+                SVNLog log = dstDir.getLog();
+                SVNProperties command = new SVNProperties();
+                command.put(SVNProperty.shortPropertyName(SVNProperty.CHANGELIST), changelistName);
+                log.logChangedEntryProperties(dstName, command);
+                log.save();
+                dstDir.runLogs();
+            }
+        }
         SVNEvent event = SVNEventFactory.createSVNEvent(dst, SVNNodeKind.FILE, null, SVNRepository.INVALID_REVISION, SVNEventAction.ADD, null, null, null);
         dstAccess.handleEvent(event);
     }
 
     private void copyAddedFileAdm(File src, SVNWCAccess srcAccess, SVNWCAccess dstAccess, File dstParent, String dstName, boolean isAdded) throws SVNException {
         File dst = new File(dstParent, dstName);
-        SVNFileUtil.copyFile(src, dst, false);
+        SVNFileType srcType = SVNFileType.getType(src);
+        if (srcType == SVNFileType.SYMLINK) {
+            String linkName = SVNFileUtil.getSymlinkName(src);
+            SVNFileUtil.createSymlink(dst, linkName);
+        } else {
+            SVNFileUtil.copyFile(src, dst, false);
+        }
         if (isAdded) {
             SVNWCManager.add(dst, dstAccess.getAdminArea(dstParent), null, SVNRepository.INVALID_REVISION, SVNDepth.INFINITY);
             copyProps(src, dst, srcAccess, dstAccess);
