@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -211,11 +211,12 @@ public class SVNDiffEditor implements ISVNEditor {
         }
         if (!entry.isScheduledForDeletion()) {
             if (getDiffCallback().isDiffCopiedAsAdded() && entry.isCopied()) {
+                baseProps = new SVNProperties();
                 propDiff = dir.getProperties(fileName).asMap();
             } else {
+                baseProps = dir.getBaseProperties(fileName).asMap();
                 boolean modified = dir.hasPropModifications(fileName);
                 if (modified) {
-                    baseProps = dir.getBaseProperties(fileName).asMap();
                     propDiff = computePropsDiff(baseProps, dir.getProperties(fileName).asMap());
                 } else {
                     propDiff = new SVNProperties();
@@ -616,8 +617,9 @@ public class SVNDiffEditor implements ISVNEditor {
         String keywords = properties.getStringPropertyValue(SVNProperty.KEYWORDS);
         String eolStyle = properties.getStringPropertyValue(SVNProperty.EOL_STYLE);
         String charsetProp = properties.getStringPropertyValue(SVNProperty.CHARSET);
+        String mimeType = properties.getStringPropertyValue(SVNProperty.MIME_TYPE);
         ISVNOptions options = dir.getWCAccess().getOptions();
-        String charset = SVNTranslator.getCharset(charsetProp, dir.getFile(name).getPath(), options);
+        String charset = SVNTranslator.getCharset(charsetProp, mimeType, dir.getFile(name).getPath(), options);
         boolean special = properties.getPropertyValue(SVNProperty.SPECIAL) != null;
         if (charset == null && keywords == null && eolStyle == null && (!special || !SVNFileUtil.symlinksSupported())) {
             return dir.getFile(name);
