@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -179,6 +179,10 @@ public class SVNFileUtil {
         } catch (NoSuchMethodException e) {
         }
     }
+    
+    public static boolean isCaseInsensitiveFS() {
+        return isWindows || isOS2;
+    }
 
     public static synchronized boolean useUnsafeCopyOnly() {
         return ourUseUnsafeCopyOnly;
