@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -104,7 +104,7 @@ public class SVNMergeCallback extends AbstractDiffCallback {
             }
             
             MergeSource mergeSource = myMergeDriver.getCurrentMergeSource();
-            if (mergeSource.getRevision1() < mergeSource.getRevision2()) {
+            if (mergeSource.getRevision1() < mergeSource.getRevision2() || !myMergeDriver.myAreSourcesAncestral) {
                 SVNProperties filteredProps = myMergeDriver.filterSelfReferentialMergeInfo(regularProps, file); 
                 if (filteredProps != null) {
                     regularProps = filteredProps; 
@@ -345,6 +345,13 @@ public class SVNMergeCallback extends AbstractDiffCallback {
                 if (same) {
                     if (!myIsDryRun && !myIsAddNecessitatedMerge) {
                         SVNFileUtil.rename(file2, mergedFile);
+                        boolean executable = false;
+                        if (diff != null && diff.containsName(SVNProperty.EXECUTABLE)) {
+                            executable = diff.getStringValue(SVNProperty.EXECUTABLE) != null;
+                        } else {
+                            executable = originalProperties != null && originalProperties.getStringValue(SVNProperty.EXECUTABLE) != null;
+                        }                    
+                        SVNFileUtil.setExecutable(mergedFile, executable);
                     }
                     result[0] = SVNStatusType.CHANGED;
                     needsMerge = false;
@@ -376,6 +383,7 @@ public class SVNMergeCallback extends AbstractDiffCallback {
                     myConflictedPaths.put(path, path);
                 }
             }
+            // if file is marked as executable
         } 
         return result;
     }
@@ -384,7 +392,7 @@ public class SVNMergeCallback extends AbstractDiffCallback {
             String mimeType1, String mimeType2, SVNProperties originalProperties, SVNProperties diff, boolean[] isTreeConflicted) throws SVNException {
         setIsConflicted(isTreeConflicted, false);
         SVNStatusType[] result = new SVNStatusType[] {null, SVNStatusType.UNKNOWN};
-        SVNProperties newProps = new SVNProperties(originalProperties);
+        SVNProperties fileProps = new SVNProperties(originalProperties);
         for (Iterator propChangesIter = diff.nameSet().iterator(); propChangesIter.hasNext();) {
             String propName = (String) propChangesIter.next();
             if (SVNProperty.isWorkingCopyProperty(propName)) {
@@ -397,14 +405,14 @@ public class SVNMergeCallback extends AbstractDiffCallback {
                 continue;
             }
             SVNPropertyValue propValue = diff.getSVNPropertyValue(propName);
-            newProps.put(propName, propValue);
+            fileProps.put(propName, propValue);
         }
         File mergedFile = getFile(path);
         SVNAdminArea dir = retrieve(mergedFile.getParentFile(), true);
         if (dir == null) {
             if (myIsDryRun && myAddedPath != null && SVNPathUtil.isAncestor(myAddedPath, path)) {
                 result[0] = SVNStatusType.CHANGED;
-                if (!newProps.isEmpty()) {
+                if (!fileProps.isEmpty()) {
                     result[1] = SVNStatusType.CHANGED;
                 }
             } else {
@@ -423,14 +431,33 @@ public class SVNMergeCallback extends AbstractDiffCallback {
             if (!myIsDryRun) {
                 String copyFromURL = null;
                 long copyFromRevision = SVNRepository.INVALID_REVISION;
+                SVNProperties newProps, newBaseProps;
+                File newBaseFile, newFile;
+                
                 if (myMergeDriver.myIsSameRepository) {
                     String targePath = myMergeDriver.myTarget.getAbsolutePath();
                     String minePath = mergedFile.getAbsolutePath();
                     String relativePath = SVNPathUtil.getRelativePath(targePath, minePath);
 
-                    copyFromURL = myURL.appendPath(relativePath, false).toString();    
-                    copyFromRevision = revision2;
+                    if (relativePath != null) {
+                        copyFromURL = myURL.appendPath(relativePath, false).toString();
+                    } else {
+                        copyFromURL = myURL.toString();
+                    }
                     // TODO compare protocols with dir one.
+
+                    copyFromRevision = revision2;
+                    newBaseProps = fileProps;
+                    newProps = null;
+                    newBaseFile = file2;
+                    newFile = null;
+                } else {
+                    copyFromURL = null;
+                    copyFromRevision = -1;
+                    newBaseProps = new SVNProperties();
+                    newProps = fileProps;
+                    newBaseFile = null;
+                    newFile = file2;
                 }
                 
                 SVNTreeConflictDescription existingConflict = getWCAccess().getTreeConflict(mergedFile);
@@ -438,12 +465,12 @@ public class SVNMergeCallback extends AbstractDiffCallback {
                     myMergeDriver.recordTreeConflictOnAdd(mergedFile, getAdminArea(), SVNNodeKind.FILE, SVNConflictAction.ADD, SVNConflictReason.ADDED);
                     setIsConflicted(isTreeConflicted, true);
                 } else {
-                    SVNWCManager.addRepositoryFile(dir, mergedFile.getName(), null, file2, newProps, null, 
+                    SVNWCManager.addRepositoryFile(dir, mergedFile.getName(), newFile, newBaseFile, newBaseProps, newProps, 
                             copyFromURL, copyFromRevision);
                 }
             }
             result[0] = SVNStatusType.CHANGED;
-            if (!newProps.isEmpty()) {
+            if (!fileProps.isEmpty()) {
                 result[1] = SVNStatusType.CHANGED;
             }
         } else if (fileType == SVNFileType.DIRECTORY) {
