@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -65,7 +65,7 @@ public class SVNMergeCallback15 extends SVNMergeCallback {
             }
             
             MergeSource mergeSource = myMergeDriver.getCurrentMergeSource();
-            if (mergeSource.getRevision1() < mergeSource.getRevision2()) {
+            if (mergeSource.getRevision1() < mergeSource.getRevision2() || !myMergeDriver.myAreSourcesAncestral) {
                 SVNProperties filteredProps = myMergeDriver.filterSelfReferentialMergeInfo(regularProps, file); 
                 if (filteredProps != null) {
                     regularProps = filteredProps; 
@@ -251,6 +251,13 @@ public class SVNMergeCallback15 extends SVNMergeCallback {
                 if (same) {
                     if (!myIsDryRun && !myIsAddNecessitatedMerge) {
                         SVNFileUtil.rename(file2, mergedFile);
+                        boolean executable = false;
+                        if (diff != null && diff.containsName(SVNProperty.EXECUTABLE)) {
+                            executable = diff.getStringValue(SVNProperty.EXECUTABLE) != null;
+                        } else {
+                            executable = originalProperties != null && originalProperties.getStringValue(SVNProperty.EXECUTABLE) != null;
+                        }                    
+                        SVNFileUtil.setExecutable(mergedFile, executable);
                     }
                     result[0] = SVNStatusType.CHANGED;
                     needsMerge = false;
