@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -11,15 +11,6 @@
  */
 package org.tmatesoft.svn.core.internal.wc;
 
-import java.io.File;
-import java.io.IOException;
-import java.io.InputStream;
-import java.io.OutputStream;
-import java.util.Collection;
-import java.util.Iterator;
-import java.util.Map;
-import java.util.StringTokenizer;
-
 import org.tmatesoft.svn.core.SVNDepth;
 import org.tmatesoft.svn.core.SVNErrorCode;
 import org.tmatesoft.svn.core.SVNErrorMessage;
@@ -45,6 +36,15 @@ import org.tmatesoft.svn.core.wc.SVNEventAction;
 import org.tmatesoft.svn.core.wc.SVNStatusType;
 import org.tmatesoft.svn.util.SVNLogType;
 
+import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.util.Collection;
+import java.util.Iterator;
+import java.util.Map;
+import java.util.StringTokenizer;
+
 
 /**
  * @author TMate Software Ltd.
@@ -161,7 +161,7 @@ public class SVNPropertiesManager {
 
 
         if (propValue != null && SVNProperty.isSVNProperty(propName)) {
-            propValue = validatePropertyValue(path.getAbsolutePath(), entry.getKind(), propName, propValue, skipChecks, access.getOptions(), new ISVNFileContentFetcher() {
+            propValue = validatePropertyValue(path, entry.getKind(), propName, propValue, skipChecks, access.getOptions(), new ISVNFileContentFetcher() {
 
                 public void fetchFileContent(OutputStream os) throws SVNException {
                     InputStream is = SVNFileUtil.openFileForReading(path, SVNLogType.WC);
@@ -177,9 +177,13 @@ public class SVNPropertiesManager {
                 }
 
                 public boolean fileIsBinary() throws SVNException {
-                    SVNPropertyValue mimeType = getProperty(access, path, SVNProperty.MIME_TYPE);
+                    SVNPropertyValue mimeType = SVNPropertiesManager.getProperty(access, path, SVNProperty.MIME_TYPE);
                     return mimeType != null && SVNProperty.isBinaryMimeType(mimeType.getString());
                 }
+
+                public SVNPropertyValue getProperty(String propertyName) throws SVNException {
+                    return SVNPropertiesManager.getProperty(access, path, propertyName);
+                }
             });
         }
 
@@ -412,7 +416,7 @@ public class SVNPropertiesManager {
         return false;
     }
 
-    public static SVNPropertyValue validatePropertyValue(String path, SVNNodeKind kind, String name, SVNPropertyValue value, boolean force, ISVNOptions options, ISVNFileContentFetcher fileContentFetcher) throws SVNException {
+    public static SVNPropertyValue validatePropertyValue(Object path, SVNNodeKind kind, String name, SVNPropertyValue value, boolean force, ISVNOptions options, ISVNFileContentFetcher fileContentFetcher) throws SVNException {
         if (value == null) {
             return value;
         }
@@ -436,7 +440,7 @@ public class SVNPropertiesManager {
         } else if (!force && SVNProperty.CHARSET.equals(name)) {
             value = SVNPropertyValue.create(value.getString().trim());
             try {
-                SVNTranslator.getCharset(value.getString(), path, options);
+                SVNTranslator.getCharset(value.getString(), null, path, options);
             } catch (SVNException e) {
                 SVNErrorMessage error = SVNErrorMessage.create(SVNErrorCode.ILLEGAL_TARGET, "Charset ''{0}'' is not supported on this computer", value.getString());
                 SVNErrorManager.error(error, SVNLogType.DEFAULT);
@@ -448,6 +452,12 @@ public class SVNPropertiesManager {
         } else if (!force && SVNProperty.MIME_TYPE.equals(name)) {
             value = SVNPropertyValue.create(value.getString().trim());
             validateMimeType(value.getString());
+            if (SVNProperty.isBinaryMimeType(value.getString())) {
+                if (fileContentFetcher.getProperty(SVNProperty.EOL_STYLE) != null) {
+                    SVNErrorMessage error = SVNErrorMessage.create(SVNErrorCode.ILLEGAL_TARGET, "File ''{0}'' has svn:eol-style property set and thus cannot have binary mime type", path);
+                    SVNErrorManager.error(error, SVNLogType.DEFAULT);
+                }
+            }
         } else if (SVNProperty.IGNORE.equals(name) || SVNProperty.EXTERNALS.equals(name)) {
             if (!value.getString().endsWith("\n")) {
                 value = SVNPropertyValue.create(value.getString().concat("\n"));
@@ -479,7 +489,7 @@ public class SVNPropertiesManager {
         return false;
     }
 
-    private static void validatePropertyName(String path, String name, SVNNodeKind kind) throws SVNException {
+    private static void validatePropertyName(Object path, String name, SVNNodeKind kind) throws SVNException {
         SVNErrorMessage err = null;
         if (kind == SVNNodeKind.DIR) {
             if (NOT_ALLOWED_FOR_DIR.contains(name)) {
@@ -512,7 +522,29 @@ public class SVNPropertiesManager {
         }
     }
 
-    public static void validateEOLProperty(String path, ISVNFileContentFetcher fetcher) throws SVNException {
+    public static String determineEncodingByMimeType(String mimeType) {
+        if (mimeType == null) {
+            return null;
+        }
+        if (!SVNProperty.isTextMimeType(mimeType)) {
+            return null;
+        }
+        for (StringTokenizer tokenizer = new StringTokenizer(mimeType, ";", false); tokenizer.hasMoreTokens();) {
+            String token = tokenizer.nextToken();
+            token = token.trim();
+            if (!token.startsWith("charset")) {
+                continue;
+            }
+            token = token.substring("charset".length()).trim();
+            if (!token.startsWith("=")) {
+                continue;
+            }
+            return token.substring("=".length()).trim();
+        }
+        return null;
+    }
+
+    public static void validateEOLProperty(Object path, ISVNFileContentFetcher fetcher) throws SVNException {
         SVNTranslatorOutputStream out = new SVNTranslatorOutputStream(SVNFileUtil.DUMMY_OUT, new byte[0], false, null, false);
 
         try {
@@ -537,7 +569,7 @@ public class SVNPropertiesManager {
         }
     }
 
-    private static void handleInconsistentEOL(SVNException svne, String path) throws SVNException {
+    private static void handleInconsistentEOL(SVNException svne, Object path) throws SVNException {
         SVNErrorMessage errorMessage = svne.getErrorMessage();
         while (errorMessage != null && errorMessage.getErrorCode() != SVNErrorCode.IO_INCONSISTENT_EOL) {
             errorMessage = errorMessage.getChildErrorMessage();
