@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -393,7 +393,7 @@ public class SVNRemoteStatusEditor extends SVNStatusEditor implements ISVNEditor
     }
     
     public void handleStatus(SVNStatus status) throws SVNException {
-        status.setContentsStatus(SVNStatusType.STATUS_DELETED);
+        status.setRemoteStatus(SVNStatusType.STATUS_DELETED, null, null, null);
         getDefaultHandler().handleStatus(status);
     }
     
