@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -18,6 +18,7 @@ import org.tmatesoft.svn.core.SVNLock;
 import org.tmatesoft.svn.core.SVNNodeKind;
 import org.tmatesoft.svn.core.SVNProperty;
 import org.tmatesoft.svn.core.SVNURL;
+import org.tmatesoft.svn.core.internal.util.SVNDate;
 import org.tmatesoft.svn.core.internal.util.SVNHashMap;
 import org.tmatesoft.svn.core.internal.util.SVNHashSet;
 import org.tmatesoft.svn.core.internal.util.SVNPathUtil;
@@ -28,6 +29,7 @@ import org.tmatesoft.svn.core.internal.wc.admin.SVNWCAccess;
 import org.tmatesoft.svn.core.wc.ISVNOptions;
 import org.tmatesoft.svn.core.wc.ISVNStatusFileProvider;
 import org.tmatesoft.svn.core.wc.ISVNStatusHandler;
+import org.tmatesoft.svn.core.wc.SVNRevision;
 import org.tmatesoft.svn.core.wc.SVNStatus;
 import org.tmatesoft.svn.core.wc.SVNStatusType;
 import org.tmatesoft.svn.core.wc.SVNTreeConflictDescription;
@@ -137,7 +139,7 @@ public class SVNStatusEditor {
             myAdminInfo.addExternal(path, externals, externals);
             myAdminInfo.addDepth(path, dirEntry.getDepth());
             
-            SVNExternal[] externalsInfo = SVNExternal.parseExternals(dir.getRelativePath(myAdminInfo.getAnchor()), externals);
+            SVNExternal[] externalsInfo = SVNExternal.parseExternals(myAdminInfo.getAnchor(), externals);
             for (int i = 0; i < externalsInfo.length; i++) {
                 SVNExternal external = externalsInfo[i];
                 myExternalsMap.put(SVNPathUtil.append(path, external.getPath()), external);
@@ -188,10 +190,13 @@ public class SVNStatusEditor {
         childrenFiles = new TreeMap(childrenFiles);
         for (Iterator files = childrenFiles.keySet().iterator(); files.hasNext();) {
             String fileName = (String) files.next();
-            if (dir.getEntry(fileName, false) != null || SVNFileUtil.getAdminDirectoryName().equals(fileName)) {
+            SVNEntry entry = dir.getEntry(fileName, true);
+            if (isNameConflict(entry)) {
+                continue;
+            }
+            if ((entry != null && !entry.isHidden()) || SVNFileUtil.getAdminDirectoryName().equals(fileName)) {
                 continue;
             }
-
             File file = (File) childrenFiles.get(fileName);
             if (depth == SVNDepth.FILES && file.isDirectory()) {
                 continue;
@@ -219,8 +224,22 @@ public class SVNStatusEditor {
                     handler);
         }
        
-        for(Iterator entries = dir.entries(false); entries.hasNext();) {
+        for(Iterator entries = dir.entries(true); entries.hasNext();) {
             SVNEntry entry = (SVNEntry) entries.next();
+            if (isNameConflict(entry)) {
+                SVNStatus status = new SVNStatus(entry.getSVNURL(), dir.getFile(entry.getName()), entry.getKind(),
+                        SVNRevision.create(entry.getRevision()), SVNRevision.create(entry.getCommittedRevision()),
+                        SVNDate.parseDate(entry.getCommittedDate()), entry.getAuthor(),
+                        SVNStatusType.STATUS_NAME_CONFLICT,  SVNStatusType.STATUS_NONE, SVNStatusType.STATUS_NONE, SVNStatusType.STATUS_NONE, 
+                        false, entry.isCopied(), false, false, null, null, null, null, 
+                        entry.getCopyFromURL(), SVNRevision.create(entry.getCopyFromRevision()),
+                        null, null, entry.asMap(), entry.getChangelistName(), dir.getFormatVersion(), null);                
+                status.setEntry(entry);
+                handler.handleStatus(status);                
+                continue;
+            } else if (entry.isHidden()) {
+                continue;
+            }
             if (dir.getThisDirName().equals(entry.getName())) {
                 continue;
             }
@@ -237,6 +256,10 @@ public class SVNStatusEditor {
         }
     }
 
+    public static boolean isNameConflict(SVNEntry entry) {        
+        return entry != null && entry.isAbsent() && "nameconflict".equals(entry.getChecksum());
+    }
+
     protected void cleanup() {
         if (hasTarget()) { 
             myAdminInfo.removeExternal("");
