@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -689,6 +689,21 @@ public class SVNUpdateEditor15 implements ISVNUpdateEditor, ISVNCleanupHandler {
         }
                 
         entry.setIncomplete(false);
+        if (!myIsDepthSticky && entry.isThisDir() && 
+                myRequestedDepth == SVNDepth.IMMEDIATES) {
+            int directoryDepth = SVNPathUtil.getSegmentsCount(dirInfo.getPath());
+            if (myTarget != null && !"".equals(myTarget)) {
+                directoryDepth--;
+            }
+            if (directoryDepth > 0) {
+                SVNDepth ambientDepth = dirInfo.myAmbientDepth;
+                if (ambientDepth == null || 
+                        ambientDepth == SVNDepth.UNKNOWN || 
+                        ambientDepth.compareTo(SVNDepth.EMPTY) > 0) {
+                    entry.setIncomplete(true);
+                }
+            }
+        } 
         File target = myAdminInfo.getTarget().getRoot();
 
         if (myIsDepthSticky && (myRequestedDepth == SVNDepth.INFINITY || (adminArea.getRoot().equals(target) && 
