@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -302,7 +302,7 @@ public class SVNWCAccess implements ISVNEventHandler {
         } catch (SVNException svne) {
             SVNFileType childKind = SVNFileType.getType(path);
             SVNErrorCode errCode = svne.getErrorMessage().getErrorCode(); 
-            if (!path.equals(dir) && childKind == SVNFileType.DIRECTORY && errCode == SVNErrorCode.WC_NOT_DIRECTORY) {
+            if (!path.equals(dir) && (childKind == SVNFileType.DIRECTORY || childKind == SVNFileType.NONE) && errCode == SVNErrorCode.WC_NOT_DIRECTORY) {
                 SVNErrorMessage err = SVNErrorMessage.create(SVNErrorCode.WC_NOT_DIRECTORY, "''{0}'' is not a working copy", path);
                 SVNErrorManager.error(err, logLevel, SVNLogType.WC);
             } else {
@@ -814,7 +814,7 @@ public class SVNWCAccess implements ISVNEventHandler {
         return changeLists == null || changeLists.isEmpty() || (entry != null && entry.getChangelistName() != null && changeLists.contains(entry.getChangelistName()));
     }
 
-    private int getMaxFormatVersion() {
+    int getMaxFormatVersion() {
         int maxVersion = -1;
         for (Iterator iterator = myAdminAreas.values().iterator(); iterator.hasNext();) {
             SVNAdminArea adminArea = (SVNAdminArea) iterator.next();
