@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -61,8 +61,8 @@ import de.regnis.q.sequence.line.diff.QDiffUniGenerator;
  */
 public class DefaultSVNDiffGenerator implements ISVNDiffGenerator {
 
-    protected static final byte[] PROPERTIES_SEPARATOR = "___________________________________________________________________".getBytes();
-    protected static final byte[] HEADER_SEPARATOR = "===================================================================".getBytes();
+    protected static final String PROPERTIES_SEPARATOR = "___________________________________________________________________";
+    protected static final String HEADER_SEPARATOR = "===================================================================";
     protected static final String WC_REVISION_LABEL = "(working copy)";
     protected static final InputStream EMPTY_FILE_IS = SVNFileUtil.DUMMY_IN;
 
@@ -88,9 +88,10 @@ public class DefaultSVNDiffGenerator implements ISVNDiffGenerator {
      *
      */
     public DefaultSVNDiffGenerator() {
-        myIsDiffDeleted = true;
         myAnchorPath1 = "";
         myAnchorPath2 = "";
+        setDiffDeleted(true);
+        setDiffAdded(true);
     }
 
     /**
@@ -312,7 +313,7 @@ public class DefaultSVNDiffGenerator implements ISVNDiffGenerator {
             bos.write(getEOL());
             bos.write(("Property changes on: " + (useLocalFileSeparatorChar() ? path.replace('/', File.separatorChar) : path)).getBytes(getEncoding()));
             bos.write(getEOL());
-            bos.write(PROPERTIES_SEPARATOR);
+            bos.write(PROPERTIES_SEPARATOR.getBytes(getEncoding()));
             bos.write(getEOL());
             for (Iterator changedPropNames = diff.nameSet().iterator(); changedPropNames.hasNext();) {
                 String name = (String) changedPropNames.next();
@@ -596,7 +597,7 @@ public class DefaultSVNDiffGenerator implements ISVNDiffGenerator {
         String header;
         try {
             bos.close();
-            header = bos.toString();            
+            header = bos.toString(getEncoding());            
         } catch (IOException inner) {
             header = "";
         }
@@ -660,6 +661,32 @@ public class DefaultSVNDiffGenerator implements ISVNDiffGenerator {
         return myEncoding != null;
     }
 
+    /**
+
+     * Says whether this generator is using any special (non-native)
+     * EOL bytes for outputting diffs.
+     *
+     * @return <span class="javakeyword">true</span> if yes;
+     *         otherwise <span class="javakeyword">false</span>
+     */
+    public boolean hasEOL() {
+        return myEOL != null;
+    }
+
+    /**
+     * Returns the encoding specified by svnkit.global-charset option
+     * of the global configuration.
+     *
+     * @return global charset name 
+     */
+    public String getGlobalEncoding() {
+        if (getOptions() instanceof DefaultSVNOptions) {
+            DefaultSVNOptions defaultOptions = (DefaultSVNOptions) getOptions();
+            return defaultOptions.getGlobalCharset();
+        }
+        return null;
+    }
+
     /**
      * Sets the EOL bytes to use in diff output.
      * 
@@ -807,14 +834,14 @@ public class DefaultSVNDiffGenerator implements ISVNDiffGenerator {
             os.write(path.getBytes(getEncoding()));
             os.write(" (deleted)".getBytes(getEncoding()));
             os.write(getEOL());
-            os.write(HEADER_SEPARATOR);
+            os.write(HEADER_SEPARATOR.getBytes(getEncoding()));
             os.write(getEOL());
             return true;
         }
         os.write("Index: ".getBytes(getEncoding()));
         os.write(path.getBytes(getEncoding()));
         os.write(getEOL());
-        os.write(HEADER_SEPARATOR);
+        os.write(HEADER_SEPARATOR.getBytes(getEncoding()));
         os.write(getEOL());
         return false;
     }
