@@ -1,6 +1,6 @@
 /*
  * ====================================================================
- * Copyright (c) 2004-2010 TMate Software Ltd.  All rights reserved.
+ * Copyright (c) 2004-2011 TMate Software Ltd.  All rights reserved.
  *
  * This software is licensed as described in the file COPYING, which
  * you should have received as part of this distribution.  The terms
@@ -632,6 +632,7 @@ public class SVNBasicClient implements ISVNEventHandler {
 
         if (!reposOnly) {
             mergeInfo = getWCMergeInfo(path, entry, null, inherit, false, indirect);
+            SVNDebugLog.getDefaultLog().logFinest(SVNLogType.WC, "merge: mergeinfo fetched from the working copy: " + mergeInfo);
         }
         
         if (mergeInfo == null) {            
@@ -656,6 +657,7 @@ public class SVNBasicClient implements ISVNEventHandler {
                             repository.setLocation(url, false);
                         }
                         reposMergeInfo = getReposMergeInfo(repository, repositoryPath, revision, inherit, true);
+                        SVNDebugLog.getDefaultLog().logFinest(SVNLogType.WC, "merge: mergeinfo fetched from repository: " + reposMergeInfo);
                     } finally {
                         if (closeRepository) {
                             repository.closeSession();
@@ -694,6 +696,7 @@ public class SVNBasicClient implements ISVNEventHandler {
                     inherit = SVNMergeInfoInheritance.INHERITED;
                 } else {
                     wcMergeInfo = SVNPropertiesManager.parseMergeInfo(path, entry, base);
+                    SVNDebugLog.getDefaultLog().logFinest(SVNLogType.WC, "merge: mergeinfo fetched from the working copy path: " + path + " = " + wcMergeInfo);
                 }
 
                 if (SVNWCManager.isEntrySwitched(path, entry)) {
@@ -806,7 +809,7 @@ public class SVNBasicClient implements ISVNEventHandler {
         return absPath;
     }
 
-    protected String getPathRelativeToSession(SVNURL url, SVNURL sessionURL, SVNRepository repos) throws SVNException {
+    protected String getPathRelativeToSession(SVNURL url, SVNURL sessionURL, SVNRepository repos) {
         if (sessionURL == null) {
             sessionURL = repos.getLocation();
         }
